@@ -1,9 +1,12 @@
-from __future__ import division, print_function
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
+from matplotlib.externals import six
 
 import os, sys, warnings
 def fn_name(): return sys._getframe(1).f_code.co_name
 
-if sys.version_info[0] >= 3:
+if six.PY3:
     warnings.warn(
         "The gtk* backends have not been tested with Python 3.x",
         ImportWarning)
@@ -240,14 +243,11 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
         self.set_flags(gtk.CAN_FOCUS)
         self._renderer_init()
 
-        self._idle_event_id = gobject.idle_add(self.idle_event)
-
         self.last_downclick = {}
 
     def destroy(self):
         #gtk.DrawingArea.destroy(self)
         self.close_event()
-        gobject.source_remove(self._idle_event_id)
         if self._idle_draw_id != 0:
             gobject.source_remove(self._idle_draw_id)
 
@@ -326,7 +326,7 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
 
     def enter_notify_event(self, widget, event):
         x, y, state = event.window.get_pointer()
-        FigureCanvasBase.enter_notify_event(self, event, xy=(x,y))
+        FigureCanvasBase.enter_notify_event(self, event, xy=(x, y))
 
     def _get_key(self, event):
         if event.keyval in self.keyvald:
@@ -339,7 +339,7 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
         for key_mask, prefix in (
                                  [gdk.MOD4_MASK, 'super'],
                                  [gdk.MOD1_MASK, 'alt'],
-                                 [gdk.CONTROL_MASK, 'ctrl'],):
+                                 [gdk.CONTROL_MASK, 'ctrl'], ):
             if event.state & key_mask:
                 key = '{0}+{1}'.format(prefix, key)
 
@@ -360,7 +360,6 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
 
         return False  # finish event propagation?
 
-
     def draw(self):
         # Note: FigureCanvasBase.draw() is inconveniently named as it clashes
         # with the deprecated gtk.Widget.draw()
@@ -373,12 +372,15 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
             self.window.process_updates (False)
 
     def draw_idle(self):
+        if self._idle_draw_id != 0:
+            return
         def idle_draw(*args):
-            self.draw()
-            self._idle_draw_id = 0
+            try:
+                self.draw()
+            finally:
+                self._idle_draw_id = 0
             return False
-        if self._idle_draw_id == 0:
-            self._idle_draw_id = gobject.idle_add(idle_draw)
+        self._idle_draw_id = gobject.idle_add(idle_draw)
 
 
     def _renderer_init(self):
@@ -453,7 +455,7 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
     def print_png(self, filename, *args, **kwargs):
         return self._print_image(filename, 'png')
 
-    def _print_image(self, filename, format):
+    def _print_image(self, filename, format, *args, **kwargs):
         if self.flags() & gtk.REALIZED == 0:
             # for self.window(for pixmap) and has a side effect of altering
             # figure width,height (via configure-event?)
@@ -470,9 +472,18 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
         pixbuf.get_from_drawable(pixmap, pixmap.get_colormap(),
                                      0, 0, 0, 0, width, height)
 
+        # set the default quality, if we are writing a JPEG.
+        # http://www.pygtk.org/docs/pygtk/class-gdkpixbuf.html#method-gdkpixbuf--save
+        options = cbook.restrict_dict(kwargs, ['quality'])
+        if format in ['jpg','jpeg']:
+            if 'quality' not in options:
+                options['quality'] = rcParams['savefig.jpeg_quality']
+
+            options['quality'] = str(options['quality'])
+
         if is_string_like(filename):
             try:
-                pixbuf.save(filename, format)
+                pixbuf.save(filename, format, options=options)
             except gobject.GError as exc:
                 error_msg_gtk('Save figure failure:\n%s' % (exc,), parent=self)
         elif is_writable_file_like(filename):
@@ -480,7 +491,7 @@ class FigureCanvasGTK (gtk.DrawingArea, FigureCanvasBase):
                 def save_callback(buf, data=None):
                     data.write(buf)
                 try:
-                    pixbuf.save_to_callback(save_callback, format, user_data=filename)
+                    pixbuf.save_to_callback(save_callback, format, user_data=filename, options=options)
                 except gobject.GError as exc:
                     error_msg_gtk('Save figure failure:\n%s' % (exc,), parent=self)
             else:
@@ -573,6 +584,7 @@ class FigureManagerGTK(FigureManagerBase):
         self.window.connect("delete_event", destroy)
         if matplotlib.is_interactive():
             self.window.show()
+            self.canvas.draw_idle()
 
         def notify_axes_change(fig):
             'this will be called whenever the current axes is changed'
@@ -614,9 +626,7 @@ class FigureManagerGTK(FigureManagerBase):
     def _get_toolbar(self, canvas):
         # must be inited after the window, drawingArea and figure
         # attrs are set
-        if rcParams['toolbar'] == 'classic':
-            toolbar = NavigationToolbar (canvas, self.window)
-        elif rcParams['toolbar'] == 'toolbar2':
+        if rcParams['toolbar'] == 'toolbar2':
             toolbar = NavigationToolbar2GTK (canvas, self.window)
         else:
             toolbar = None
@@ -733,14 +743,24 @@ class NavigationToolbar2GTK(NavigationToolbar2, gtk.Toolbar):
         fc = FileChooserDialog(
             title='Save the figure',
             parent=self.win,
+            path=os.path.expanduser(rcParams.get('savefig.directory', '')),
             filetypes=self.canvas.get_supported_filetypes(),
             default_filetype=self.canvas.get_default_filetype())
         fc.set_current_name(self.canvas.get_default_filename())
         return fc
 
     def save_figure(self, *args):
-        fname, format = self.get_filechooser().get_filename_from_user()
+        chooser = self.get_filechooser()
+        fname, format = chooser.get_filename_from_user()
+        chooser.destroy()
         if fname:
+            startpath = os.path.expanduser(rcParams.get('savefig.directory', ''))
+            if startpath == '':
+                # explicitly missing key or empty str signals to use cwd
+                rcParams['savefig.directory'] = startpath
+            else:
+                # save dir for next time
+                rcParams['savefig.directory'] = os.path.dirname(six.text_type(fname))
             try:
                 self.canvas.print_figure(fname, format=format)
             except Exception as e:
@@ -777,242 +797,9 @@ class NavigationToolbar2GTK(NavigationToolbar2, gtk.Toolbar):
         return FigureCanvasGTK(fig)
 
 
-class NavigationToolbar(gtk.Toolbar):
-    """
-    Public attributes
-
-      canvas - the FigureCanvas  (gtk.DrawingArea)
-      win    - the gtk.Window
-
-    """
-    # list of toolitems to add to the toolbar, format is:
-    # text, tooltip_text, image, callback(str), callback_arg, scroll(bool)
-    toolitems = (
-        ('Left', 'Pan left with click or wheel mouse (bidirectional)',
-         gtk.STOCK_GO_BACK, 'panx', -1, True),
-        ('Right', 'Pan right with click or wheel mouse (bidirectional)',
-         gtk.STOCK_GO_FORWARD, 'panx', 1, True),
-        ('Zoom In X',
-         'Zoom In X (shrink the x axis limits) with click or wheel'
-         ' mouse (bidirectional)',
-         gtk.STOCK_ZOOM_IN, 'zoomx', 1, True),
-        ('Zoom Out X',
-         'Zoom Out X (expand the x axis limits) with click or wheel'
-         ' mouse (bidirectional)',
-         gtk.STOCK_ZOOM_OUT, 'zoomx', -1, True),
-        (None, None, None, None, None, None,),
-        ('Up', 'Pan up with click or wheel mouse (bidirectional)',
-         gtk.STOCK_GO_UP, 'pany', 1, True),
-        ('Down', 'Pan down with click or wheel mouse (bidirectional)',
-         gtk.STOCK_GO_DOWN, 'pany', -1, True),
-        ('Zoom In Y',
-         'Zoom in Y (shrink the y axis limits) with click or wheel'
-         ' mouse (bidirectional)',
-         gtk.STOCK_ZOOM_IN, 'zoomy', 1, True),
-        ('Zoom Out Y',
-         'Zoom Out Y (expand the y axis limits) with click or wheel'
-         ' mouse (bidirectional)',
-         gtk.STOCK_ZOOM_OUT, 'zoomy', -1, True),
-        (None, None, None, None, None, None,),
-        ('Save', 'Save the figure',
-         gtk.STOCK_SAVE, 'save_figure', None, False),
-        )
-
-    def __init__(self, canvas, window):
-        """
-        figManager is the FigureManagerGTK instance that contains the
-        toolbar, with attributes figure, window and drawingArea
-
-        """
-        gtk.Toolbar.__init__(self)
-
-        self.canvas = canvas
-        # Note: gtk.Toolbar already has a 'window' attribute
-        self.win    = window
-
-        self.set_style(gtk.TOOLBAR_ICONS)
-
-        self._create_toolitems_2_4()
-        self.update = self._update_2_4
-        self.fileselect = FileChooserDialog(
-            title='Save the figure',
-            parent=self.win,
-            filetypes=self.canvas.get_supported_filetypes(),
-            default_filetype=self.canvas.get_default_filetype())
-        self.show_all()
-        self.update()
-
-    def _create_toolitems_2_4(self):
-        # use the GTK+ 2.4 GtkToolbar API
-        iconSize = gtk.ICON_SIZE_SMALL_TOOLBAR
-        if not _new_tooltip_api:
-            self.tooltips = gtk.Tooltips()
-
-        for text, tooltip_text, image_num, callback, callback_arg, scroll \
-                in self.toolitems:
-            if text is None:
-                self.insert( gtk.SeparatorToolItem(), -1 )
-                continue
-            image = gtk.Image()
-            image.set_from_stock(image_num, iconSize)
-            tbutton = gtk.ToolButton(image, text)
-            self.insert(tbutton, -1)
-            if callback_arg:
-                tbutton.connect('clicked', getattr(self, callback),
-                                callback_arg)
-            else:
-                tbutton.connect('clicked', getattr(self, callback))
-            if scroll:
-                tbutton.connect('scroll_event', getattr(self, callback))
-            if _new_tooltip_api:
-                tbutton.set_tooltip_text(tooltip_text)
-            else:
-                tbutton.set_tooltip(self.tooltips, tooltip_text, 'Private')
-
-        # Axes toolitem, is empty at start, update() adds a menu if >=2 axes
-        self.axes_toolitem = gtk.ToolItem()
-        self.insert(self.axes_toolitem, 0)
-        if _new_tooltip_api:
-            self.axes_toolitem.set_tooltip_text(
-                                'Select axes that controls affect')
-        else:
-            self.axes_toolitem.set_tooltip (
-                self.tooltips,
-                tip_text='Select axes that controls affect',
-                tip_private = 'Private')
-
-        align = gtk.Alignment (xalign=0.5, yalign=0.5, xscale=0.0, yscale=0.0)
-        self.axes_toolitem.add(align)
-
-        self.menubutton = gtk.Button ("Axes")
-        align.add (self.menubutton)
-
-        def position_menu (menu):
-            """Function for positioning a popup menu.
-            Place menu below the menu button, but ensure it does not go off
-            the bottom of the screen.
-            The default is to popup menu at current mouse position
-            """
-            x0, y0    = self.window.get_origin()
-            x1, y1, m = self.window.get_pointer()
-            x2, y2    = self.menubutton.get_pointer()
-            sc_h      = self.get_screen().get_height()  # requires GTK+ 2.2 +
-            w, h      = menu.size_request()
-
-            x = x0 + x1 - x2
-            y = y0 + y1 - y2 + self.menubutton.allocation.height
-            y = min(y, sc_h - h)
-            return x, y, True
-
-        def button_clicked (button, data=None):
-            self.axismenu.popup (None, None, position_menu, 0,
-                                 gtk.get_current_event_time())
-
-        self.menubutton.connect ("clicked", button_clicked)
-
-
-    def _update_2_4(self):
-        # for GTK+ 2.4+
-        # called by __init__() and FigureManagerGTK
-
-        self._axes = self.canvas.figure.axes
-
-        if len(self._axes) >= 2:
-            self.axismenu = self._make_axis_menu()
-            self.menubutton.show_all()
-        else:
-            self.menubutton.hide()
-
-        self.set_active(range(len(self._axes)))
-
-
-    def _make_axis_menu(self):
-        # called by self._update*()
-
-        def toggled(item, data=None):
-            if item == self.itemAll:
-                for item in items: item.set_active(True)
-            elif item == self.itemInvert:
-                for item in items:
-                    item.set_active(not item.get_active())
-
-            ind = [i for i,item in enumerate(items) if item.get_active()]
-            self.set_active(ind)
-
-        menu = gtk.Menu()
-
-        self.itemAll = gtk.MenuItem("All")
-        menu.append(self.itemAll)
-        self.itemAll.connect("activate", toggled)
-
-        self.itemInvert = gtk.MenuItem("Invert")
-        menu.append(self.itemInvert)
-        self.itemInvert.connect("activate", toggled)
-
-        items = []
-        for i in range(len(self._axes)):
-            item = gtk.CheckMenuItem("Axis %d" % (i+1))
-            menu.append(item)
-            item.connect("toggled", toggled)
-            item.set_active(True)
-            items.append(item)
-
-        menu.show_all()
-        return menu
-
-
-    def set_active(self, ind):
-        self._ind = ind
-        self._active = [ self._axes[i] for i in self._ind ]
-
-    def panx(self, button, direction):
-        'panx in direction'
-
-        for a in self._active:
-            a.xaxis.pan(direction)
-        self.canvas.draw()
-        return True
-
-    def pany(self, button, direction):
-        'pany in direction'
-        for a in self._active:
-            a.yaxis.pan(direction)
-        self.canvas.draw()
-        return True
-
-    def zoomx(self, button, direction):
-        'zoomx in direction'
-        for a in self._active:
-            a.xaxis.zoom(direction)
-        self.canvas.draw()
-        return True
-
-    def zoomy(self, button, direction):
-        'zoomy in direction'
-        for a in self._active:
-            a.yaxis.zoom(direction)
-        self.canvas.draw()
-        return True
-
-    def get_filechooser(self):
-        return FileChooserDialog(
-            title='Save the figure',
-            parent=self.win,
-            filetypes=self.canvas.get_supported_filetypes(),
-            default_filetype=self.canvas.get_default_filetype())
-
-    def save_figure(self, *args):
-        fname, format = self.get_filechooser().get_filename_from_user()
-        if fname:
-            try:
-                self.canvas.print_figure(fname, format=format)
-            except Exception as e:
-                error_msg_gtk(str(e), parent=self)
-
-
 class FileChooserDialog(gtk.FileChooserDialog):
-    """GTK+ 2.4 file selector which remembers the last file/directory
-    selected and presents the user with a menu of supported image formats
+    """GTK+ 2.4 file selector which presents the user with a menu
+    of supported image formats
     """
     def __init__ (self,
                   title   = 'Save file',
@@ -1046,7 +833,7 @@ class FileChooserDialog(gtk.FileChooserDialog):
         hbox.pack_start (cbox)
 
         self.filetypes = filetypes
-        self.sorted_filetypes = filetypes.items()
+        self.sorted_filetypes = list(six.iteritems(filetypes))
         self.sorted_filetypes.sort()
         default = 0
         for i, (ext, name) in enumerate(self.sorted_filetypes):
@@ -1083,10 +870,9 @@ class FileChooserDialog(gtk.FileChooserDialog):
             filename = self.get_filename()
             break
 
-        self.hide()
         return filename, self.ext
 
-class DialogLineprops:
+class DialogLineprops(object):
     """
     A GUI dialog for controlling lineprops
     """
@@ -1280,4 +1066,5 @@ def error_msg_gtk(msg, parent=None):
     dialog.destroy()
 
 
+FigureCanvas = FigureCanvasGTK
 FigureManager = FigureManagerGTK
