@@ -4,8 +4,8 @@ An experimental support for curvilinear grid.
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-import six
-from six.moves import zip
+from matplotlib.externals import six
+from matplotlib.externals.six.moves import zip
 
 # TODO :
 
