@@ -12,9 +12,7 @@
 # between the major ticks.  Here is an example that labels the months,
 # centered between the ticks
 
-import datetime
 import numpy as np
-import matplotlib
 import matplotlib.cbook as cbook
 import matplotlib.dates as dates
 import matplotlib.ticker as ticker
@@ -22,11 +20,18 @@ import matplotlib.pyplot as plt
 
 # load some financial data; apple's stock price
 fh = cbook.get_sample_data('aapl.npy.gz')
-r = np.load(fh); fh.close()
+try:
+    # Python3 cannot load python2 .npy files with datetime(object) arrays
+    # unless the encoding is set to bytes. Hovever this option was
+    # not added until numpy 1.10 so this example will only work with
+    # python 2 or with numpy 1.10 and later.
+    r = np.load(fh, encoding='bytes')
+except TypeError:
+    r = np.load(fh)
+fh.close()
 r = r[-250:]  # get the last 250 days
 
-fig = plt.figure()
-ax = fig.add_subplot(111)
+fig, ax = plt.subplots()
 ax.plot(r.date, r.adj_close)
 
 ax.xaxis.set_major_locator(dates.MonthLocator())
