@@ -8,47 +8,48 @@ correctly on images, and on how to get both of them oriented as
 desired.  In particular, note the usage of the "origin" and "extent"
 keyword arguments to imshow and contour.
 '''
-from pylab import *
+import matplotlib.pyplot as plt
+import numpy as np
+from matplotlib import mlab, cm
 
-#Default delta is large because that makes it fast, and it illustrates
+# Default delta is large because that makes it fast, and it illustrates
 # the correct registration between image and contours.
 delta = 0.5
 
-extent = (-3,4,-4,3)
+extent = (-3, 4, -4, 3)
 
-x = arange(-3.0, 4.001, delta)
-y = arange(-4.0, 3.001, delta)
-X, Y = meshgrid(x, y)
-Z1 = bivariate_normal(X, Y, 1.0, 1.0, 0.0, 0.0)
-Z2 = bivariate_normal(X, Y, 1.5, 0.5, 1, 1)
+x = np.arange(-3.0, 4.001, delta)
+y = np.arange(-4.0, 3.001, delta)
+X, Y = np.meshgrid(x, y)
+Z1 = mlab.bivariate_normal(X, Y, 1.0, 1.0, 0.0, 0.0)
+Z2 = mlab.bivariate_normal(X, Y, 1.5, 0.5, 1, 1)
 Z = (Z1 - Z2) * 10
 
-levels = arange(-2.0, 1.601, 0.4) # Boost the upper limit to avoid truncation
-                                  # errors.
+levels = np.arange(-2.0, 1.601, 0.4)  # Boost the upper limit to avoid truncation errors.
 
 norm = cm.colors.Normalize(vmax=abs(Z).max(), vmin=-abs(Z).max())
 cmap = cm.PRGn
 
-figure()
+plt.figure()
 
 
-subplot(2,2,1)
+plt.subplot(2, 2, 1)
 
-cset1 = contourf(X, Y, Z, levels,
-                        cmap=cm.get_cmap(cmap, len(levels)-1),
-                        norm=norm,
-                        )
+cset1 = plt.contourf(X, Y, Z, levels,
+                 cmap=cm.get_cmap(cmap, len(levels) - 1),
+                 norm=norm,
+                 )
 # It is not necessary, but for the colormap, we need only the
 # number of levels minus 1.  To avoid discretization error, use
 # either this number or a large number such as the default (256).
 
-#If we want lines as well as filled regions, we need to call
+# If we want lines as well as filled regions, we need to call
 # contour separately; don't try to change the edgecolor or edgewidth
 # of the polygons in the collections returned by contourf.
 # Use levels output from previous call to guarantee they are the same.
-cset2 = contour(X, Y, Z, cset1.levels,
-                        colors = 'k',
-                        hold='on')
+cset2 = plt.contour(X, Y, Z, cset1.levels,
+                colors='k',
+                hold='on')
 # We don't really need dashed contour lines to indicate negative
 # regions, so let's turn them off.
 for c in cset2.collections:
@@ -58,34 +59,34 @@ for c in cset2.collections:
 # to set up an array of colors and linewidths.
 # We are making a thick green line as a zero contour.
 # Specify the zero level as a tuple with only 0 in it.
-cset3 = contour(X, Y, Z, (0,),
-                colors = 'g',
-                linewidths = 2,
+cset3 = plt.contour(X, Y, Z, (0,),
+                colors='g',
+                linewidths=2,
                 hold='on')
-title('Filled contours')
-colorbar(cset1)
+plt.title('Filled contours')
+plt.colorbar(cset1)
 #hot()
 
 
-subplot(2,2,2)
+plt.subplot(2, 2, 2)
 
-imshow(Z, extent=extent, cmap=cmap, norm=norm)
-v = axis()
-contour(Z, levels, hold='on', colors = 'k',
+plt.imshow(Z, extent=extent, cmap=cmap, norm=norm)
+v = plt.axis()
+plt.contour(Z, levels, hold='on', colors='k',
         origin='upper', extent=extent)
-axis(v)
-title("Image, origin 'upper'")
+plt.axis(v)
+plt.title("Image, origin 'upper'")
 
-subplot(2,2,3)
+plt.subplot(2, 2, 3)
 
-imshow(Z, origin='lower', extent=extent, cmap=cmap, norm=norm)
-v = axis()
-contour(Z, levels, hold='on', colors = 'k',
+plt.imshow(Z, origin='lower', extent=extent, cmap=cmap, norm=norm)
+v = plt.axis()
+plt.contour(Z, levels, hold='on', colors='k',
         origin='lower', extent=extent)
-axis(v)
-title("Image, origin 'lower'")
+plt.axis(v)
+plt.title("Image, origin 'lower'")
 
-subplot(2,2,4)
+plt.subplot(2, 2, 4)
 
 # We will use the interpolation "nearest" here to show the actual
 # image pixels.
@@ -93,14 +94,14 @@ subplot(2,2,4)
 # This is intentional. The Z values are defined at the center of each
 # image pixel (each color block on the following subplot), so the
 # domain that is contoured does not extend beyond these pixel centers.
-im = imshow(Z, interpolation='nearest', extent=extent, cmap=cmap, norm=norm)
-v = axis()
-contour(Z, levels, hold='on', colors = 'k',
+im = plt.imshow(Z, interpolation='nearest', extent=extent, cmap=cmap, norm=norm)
+v = plt.axis()
+plt.contour(Z, levels, hold='on', colors='k',
         origin='image', extent=extent)
-axis(v)
-ylim = get(gca(), 'ylim')
-setp(gca(), ylim=ylim[::-1])
-title("Image, origin from rc, reversed y-axis")
-colorbar(im)
+plt.axis(v)
+ylim = plt.get(plt.gca(), 'ylim')
+plt.setp(plt.gca(), ylim=ylim[::-1])
+plt.title("Image, origin from rc, reversed y-axis")
+plt.colorbar(im)
 
-show()
+plt.show()
