@@ -3,7 +3,7 @@ import matplotlib
 matplotlib.use('TkAgg')
 
 from numpy import arange, sin, pi
-from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg, NavigationToolbar2TkAgg
+from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from matplotlib.figure import Figure
 
 import sys
@@ -12,19 +12,20 @@ if sys.version_info[0] < 3:
 else:
     import tkinter as Tk
 
-def destroy(e): sys.exit()
+
+def destroy(e):
+    sys.exit()
 
 root = Tk.Tk()
 root.wm_title("Embedding in TK")
-#root.bind("<Destroy>", destroy)
 
 
-f = Figure(figsize=(5,4), dpi=100)
+f = Figure(figsize=(5, 4), dpi=100)
 a = f.add_subplot(111)
-t = arange(0.0,3.0,0.01)
+t = arange(0.0, 3.0, 0.01)
 s = sin(2*pi*t)
 
-a.plot(t,s)
+a.plot(t, s)
 a.set_title('Tk embedding')
 a.set_xlabel('X axis label')
 a.set_ylabel('Y label')
@@ -35,8 +36,6 @@ canvas = FigureCanvasTkAgg(f, master=root)
 canvas.show()
 canvas.get_tk_widget().pack(side=Tk.TOP, fill=Tk.BOTH, expand=1)
 
-#toolbar = NavigationToolbar2TkAgg( canvas, root )
-#toolbar.update()
 canvas._tkcanvas.pack(side=Tk.TOP, fill=Tk.BOTH, expand=1)
 
 button = Tk.Button(master=root, text='Quit', command=sys.exit)
