@@ -4,9 +4,11 @@ An example of how to use wx or wxagg in an application with the new
 toolbar - comment out the setA_toolbar line for no toolbar
 """
 
-# Used to guarantee to use at least Wx2.8
-import wxversion
-wxversion.ensureMinimal('2.8')
+# matplotlib requires wxPython 2.8+
+# set the wxPython version in lib\site-packages\wx.pth file
+# or if you have wxversion installed un-comment the lines below
+#import wxversion
+#wxversion.ensureMinimal('2.8')
 
 from numpy import arange, sin, pi
 
@@ -25,60 +27,45 @@ from matplotlib.backends.backend_wx import NavigationToolbar2Wx
 from matplotlib.figure import Figure
 
 import wx
+import wx.lib.mixins.inspection as WIT
+
 
 class CanvasFrame(wx.Frame):
-
     def __init__(self):
-        wx.Frame.__init__(self,None,-1,
-                         'CanvasFrame',size=(550,350))
-
-        self.SetBackgroundColour(wx.NamedColour("WHITE"))
+        wx.Frame.__init__(self, None, -1,
+                          'CanvasFrame', size=(550, 350))
 
         self.figure = Figure()
         self.axes = self.figure.add_subplot(111)
-        t = arange(0.0,3.0,0.01)
-        s = sin(2*pi*t)
+        t = arange(0.0, 3.0, 0.01)
+        s = sin(2 * pi * t)
 
-        self.axes.plot(t,s)
+        self.axes.plot(t, s)
         self.canvas = FigureCanvas(self, -1, self.figure)
 
         self.sizer = wx.BoxSizer(wx.VERTICAL)
-        self.sizer.Add(self.canvas, 1, wx.LEFT | wx.TOP | wx.GROW)
+        self.sizer.Add(self.canvas, 1, wx.LEFT | wx.TOP | wx.EXPAND)
         self.SetSizer(self.sizer)
         self.Fit()
 
         self.add_toolbar()  # comment this out for no toolbar
 
-
     def add_toolbar(self):
         self.toolbar = NavigationToolbar2Wx(self.canvas)
         self.toolbar.Realize()
-        if wx.Platform == '__WXMAC__':
-            # Mac platform (OSX 10.3, MacPython) does not seem to cope with
-            # having a toolbar in a sizer. This work-around gets the buttons
-            # back, but at the expense of having the toolbar at the top
-            self.SetToolBar(self.toolbar)
-        else:
-            # On Windows platform, default window size is incorrect, so set
-            # toolbar width to figure width.
-            tw, th = self.toolbar.GetSizeTuple()
-            fw, fh = self.canvas.GetSizeTuple()
-            # By adding toolbar in sizer, we are able to put it at the bottom
-            # of the frame - so appearance is closer to GTK version.
-            # As noted above, doesn't work for Mac.
-            self.toolbar.SetSize(wx.Size(fw, th))
-            self.sizer.Add(self.toolbar, 0, wx.LEFT | wx.EXPAND)
+        # By adding toolbar in sizer, we are able to put it at the bottom
+        # of the frame - so appearance is closer to GTK version.
+        self.sizer.Add(self.toolbar, 0, wx.LEFT | wx.EXPAND)
         # update the axes menu on the toolbar
         self.toolbar.update()
 
 
-    def OnPaint(self, event):
-        self.canvas.draw()
-
-class App(wx.App):
-
+# alternatively you could use
+#class App(wx.App):
+class App(WIT.InspectableApp):
     def OnInit(self):
         'Create the main window and insert the custom frame'
+        self.Init()
         frame = CanvasFrame()
         frame.Show(True)
 
