@@ -4,9 +4,11 @@ An example of how to use wx or wxagg in an application with a custom
 toolbar
 """
 
-# Used to guarantee to use at least Wx2.8
-import wxversion
-wxversion.ensureMinimal('2.8')
+# matplotlib requires wxPython 2.8+
+# set the wxPython version in lib\site-packages\wx.pth file
+# or if you have wxversion installed un-comment the lines below
+#import wxversion
+#wxversion.ensureMinimal('2.8')
 
 from numpy import arange, sin, pi
 
@@ -22,19 +24,27 @@ from numpy.random import rand
 
 import wx
 
+
 class MyNavigationToolbar(NavigationToolbar2WxAgg):
     """
     Extend the default wx toolbar with your own event handlers
     """
     ON_CUSTOM = wx.NewId()
+
     def __init__(self, canvas, cankill):
         NavigationToolbar2WxAgg.__init__(self, canvas)
 
         # for simplicity I'm going to reuse a bitmap from wx, you'll
         # probably want to add your own.
-        self.AddSimpleTool(self.ON_CUSTOM, _load_bitmap('stock_left.xpm'),
-                           'Click me', 'Activate custom contol')
-        wx.EVT_TOOL(self, self.ON_CUSTOM, self._on_custom)
+        if 'phoenix' in wx.PlatformInfo:
+            self.AddTool(self.ON_CUSTOM, 'Click me',
+                         _load_bitmap('stock_left.xpm'),
+                         'Activate custom contol')
+            self.Bind(wx.EVT_TOOL, self._on_custom, id=self.ON_CUSTOM)
+        else:
+            self.AddSimpleTool(self.ON_CUSTOM, _load_bitmap('stock_left.xpm'),
+                               'Click me', 'Activate custom contol')
+            self.Bind(wx.EVT_TOOL, self._on_custom, id=self.ON_CUSTOM)
 
     def _on_custom(self, evt):
         # add some text to the axes in a random location in axes (0,1)
@@ -44,7 +54,7 @@ class MyNavigationToolbar(NavigationToolbar2WxAgg):
         ax = self.canvas.figure.axes[0]
 
         # generate a random location can color
-        x,y = tuple(rand(2))
+        x, y = tuple(rand(2))
         rgb = tuple(rand(3))
 
         # add the text and draw
@@ -56,57 +66,41 @@ class MyNavigationToolbar(NavigationToolbar2WxAgg):
 
 
 class CanvasFrame(wx.Frame):
-
     def __init__(self):
-        wx.Frame.__init__(self,None,-1,
-                         'CanvasFrame',size=(550,350))
+        wx.Frame.__init__(self, None, -1,
+                          'CanvasFrame', size=(550, 350))
 
-        self.SetBackgroundColour(wx.NamedColour("WHITE"))
-
-        self.figure = Figure(figsize=(5,4), dpi=100)
+        self.figure = Figure(figsize=(5, 4), dpi=100)
         self.axes = self.figure.add_subplot(111)
-        t = arange(0.0,3.0,0.01)
-        s = sin(2*pi*t)
+        t = arange(0.0, 3.0, 0.01)
+        s = sin(2 * pi * t)
 
-        self.axes.plot(t,s)
+        self.axes.plot(t, s)
 
         self.canvas = FigureCanvas(self, -1, self.figure)
 
         self.sizer = wx.BoxSizer(wx.VERTICAL)
         self.sizer.Add(self.canvas, 1, wx.TOP | wx.LEFT | wx.EXPAND)
         # Capture the paint message
-        wx.EVT_PAINT(self, self.OnPaint)
+        self.Bind(wx.EVT_PAINT, self.OnPaint)
 
         self.toolbar = MyNavigationToolbar(self.canvas, True)
         self.toolbar.Realize()
-        if wx.Platform == '__WXMAC__':
-            # Mac platform (OSX 10.3, MacPython) does not seem to cope with
-            # having a toolbar in a sizer. This work-around gets the buttons
-            # back, but at the expense of having the toolbar at the top
-            self.SetToolBar(self.toolbar)
-        else:
-            # On Windows platform, default window size is incorrect, so set
-            # toolbar width to figure width.
-            tw, th = self.toolbar.GetSizeTuple()
-            fw, fh = self.canvas.GetSizeTuple()
-            # By adding toolbar in sizer, we are able to put it at the bottom
-            # of the frame - so appearance is closer to GTK version.
-            # As noted above, doesn't work for Mac.
-            self.toolbar.SetSize(wx.Size(fw, th))
-            self.sizer.Add(self.toolbar, 0, wx.LEFT | wx.EXPAND)
+        # By adding toolbar in sizer, we are able to put it at the bottom
+        # of the frame - so appearance is closer to GTK version.
+        self.sizer.Add(self.toolbar, 0, wx.LEFT | wx.EXPAND)
 
         # update the axes menu on the toolbar
         self.toolbar.update()
         self.SetSizer(self.sizer)
         self.Fit()
 
-
     def OnPaint(self, event):
         self.canvas.draw()
         event.Skip()
 
-class App(wx.App):
 
+class App(wx.App):
     def OnInit(self):
         'Create the main window and insert the custom frame'
         frame = CanvasFrame()
